# ===== THIS FILE IS GENERATED FROM A TEMPLATE ===== #
# ============== DO NOT EDIT DIRECTLY ============== #
from enum import Enum


class StreamAxisType(Enum):
    """
    Denotes type of the stream axis.
    """

    PHYSICAL = 0
    LOCKSTEP = 1
